Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(850)

Unified Diff: pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/dartino_compiler/lib/src/diagnostic.dart ('k') | pkg/dartino_compiler/lib/src/enqueuer_mixin.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart
diff --git a/pkg/fletchc/lib/src/dynamic_call_enqueuer.dart b/pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart
similarity index 96%
rename from pkg/fletchc/lib/src/dynamic_call_enqueuer.dart
rename to pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart
index 99066c64581589f25f0cd6beb00206e1c6a77d49..fb643837ab67c84152dfe91856576178e1658475 100644
--- a/pkg/fletchc/lib/src/dynamic_call_enqueuer.dart
+++ b/pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library fletchc.dynamic_call_enqueuer;
+library dartino_compiler.dynamic_call_enqueuer;
import 'dart:collection' show
Queue;
@@ -33,13 +33,13 @@ import 'package:compiler/src/common/names.dart' show
import 'package:compiler/src/util/util.dart' show
Hashing;
-import 'fletch_compiler_implementation.dart' show
- FletchCompilerImplementation;
+import 'dartino_compiler_implementation.dart' show
+ DartinoCompilerImplementation;
-import 'fletch_enqueuer.dart' show
+import 'dartino_enqueuer.dart' show
shouldReportEnqueuingOfElement;
-import 'fletch_registry.dart' show
+import 'dartino_registry.dart' show
ClosureKind;
abstract class UsageRecorder {
@@ -55,7 +55,7 @@ abstract class UsageRecorder {
/// By "dynamic" part we mean the part that is about matching instantiated
/// classes with called instance methods.
class DynamicCallEnqueuer {
- final FletchCompilerImplementation compiler;
+ final DartinoCompilerImplementation compiler;
final Set<ClassElement> instantiatedClasses = new Set<ClassElement>();
@@ -234,7 +234,7 @@ class DynamicCallEnqueuer {
revisitClass(cls);
// Once we have found one class that implements [member], we're
// done. When we later call [enqueueInstanceMethods] (via
// [FletchEnqueuer.processQueue]) the method will be enqueued again
// (if it exists).
break;
}
@@ -234,7 +234,7 @@ class DynamicCallEnqueuer {
// Once we have found one class that implements [member], we're
// done. When we later call [enqueueInstanceMethods] (via
- // [FletchEnqueuer.processQueue]) the method will be enqueued again
+ // [DartinoEnqueuer.processQueue]) the method will be enqueued again
// (if it exists).
break;
« no previous file with comments | « pkg/dartino_compiler/lib/src/diagnostic.dart ('k') | pkg/dartino_compiler/lib/src/enqueuer_mixin.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698